@@ -3,16 +3,16 @@ package org.basex.http;
 /**
  * This enumeration contains the supported HTTP methods.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public enum HTTPMethod {
   /** GET method. */
   GET,
   /** POST method. */
-  POST,
+  POST(true),
   /** PUT method. */
-  PUT,
+  PUT(true),
   /** DELETE method. */
   DELETE,
   /** HEAD method. */
@@ -20,6 +20,22 @@ public enum HTTPMethod {
   /** OPTIONS method. */
   OPTIONS;
 
+  /** Flag showing, if body can be present in the HTTP request with the current method. */
+  public final boolean body;
+
+  /** Default constructor. */
+  private HTTPMethod() {
+    this(false);
+  }
+
+  /**
+   * Constructor, specifying a body flag.
+   * @param body body flag
+   */
+  private HTTPMethod(final boolean body) {
+    this.body = body;
+  }
+
   /**
    * Finds the specified method, or returns {@code null}.
    * @param name method name
