@@ -1,19 +1,19 @@
 package org.basex.http.rest;
 
-import org.basex.core.*;
 import org.basex.query.value.item.*;
+import org.basex.util.*;
 
 /**
  * This class assembles texts which are used in the HTTP classes.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
-public interface RESTText {
+interface RESTText {
   /** REST string.  */
   String REST = "rest";
   /** REST URI. */
-  String RESTURI = Text.URL + '/' + REST;
+  String RESTURI = Prop.URL + '/' + REST;
 
   /** Name. */
   QNm Q_DATABASES = QNm.get(REST, "databases", RESTURI);
