@@ -2,18 +2,19 @@ package org.basex.http.webdav;
 
 import java.io.*;
 
+import org.basex.server.LoginException;
 import org.basex.util.*;
 
 import com.bradmcevoy.http.exceptions.*;
 
 /**
  * Code container.
- * @param <E> return type
  *
- * @author BaseX Team 2005-13, BSD License
+ * @param <E> return type
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
-public abstract class BXCode<E> {
+abstract class BXCode<E> {
   /** Resource. */
   private final BXAbstractResource resource;
 
@@ -21,7 +22,7 @@ public abstract class BXCode<E> {
    * Constructor.
    * @param res resource
    */
-  protected BXCode(final BXAbstractResource res) {
+  BXCode(final BXAbstractResource res) {
     resource = res;
   }
 
@@ -29,12 +30,15 @@ public abstract class BXCode<E> {
    * Runs the contained code.
    * @return result
    * @throws BadRequestException bad request exception
+   * @throws NotAuthorizedException not authorized exception
    */
-  public E eval() throws BadRequestException {
+  public final E eval() throws BadRequestException, NotAuthorizedException {
     try {
       final E ret = get();
-      if(ret == null) run();
+      if (ret == null) run();
       return ret;
+    } catch(final LoginException ex) {
+      throw new NotAuthorizedException(resource);
     } catch(final IOException ex) {
       Util.errln(ex);
       throw new BadRequestException(resource, ex.getMessage());
@@ -45,10 +49,10 @@ public abstract class BXCode<E> {
    * Runs the contained code, throwing no exception.
    * @return result
    */
-  public E evalNoEx() {
+  public final E evalNoEx() {
     try {
       return eval();
-    } catch(final BadRequestException ex) {
+    } catch(final Exception ex) {
       Util.errln(ex);
       return null;
     }
