@@ -8,7 +8,7 @@ import org.basex.http.webdav.impl.WebDAVService;
 /**
  * WebDAV resource representing a collection database.
  *
- * @author BaseX Team 2005-13, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Rositsa Shadura
  * @author Dimitar Popov
  */
@@ -33,7 +33,7 @@ public final class BXDatabase extends BXFolder {
   }
 
   @Override
-  protected void rename(final String n) throws IOException {
+  void rename(final String n) throws IOException {
     service.renameDb(meta.db, n);
   }
 
