@@ -5,10 +5,10 @@ import org.basex.util.list.*;
 /**
  * Lock interface; will get obsolete after database locking has been finalized.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
-public interface Locking {
+interface Locking {
   /**
    * Puts read and write locks the specified databases.
    * Store and return the {@code token} for unlocking these objects again.
@@ -21,12 +21,6 @@ public interface Locking {
    */
   void acquire(final Proc pr, final StringList read, final StringList write);
 
-  /**
-   * Unlock all string locked by a transaction.
-   * @param write write locks to keep
-   */
-  void downgrade(final StringList write);
-
   /**
    * Unlock all string locked by a transaction.
    * @param pr process
