@@ -5,7 +5,7 @@ import org.basex.core.*;
 /**
  * Abstract class for database backup.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 abstract class ABackup extends Command {
@@ -13,7 +13,7 @@ abstract class ABackup extends Command {
    * Protected constructor.
    * @param a arguments
    */
-  protected ABackup(final String... a) {
+  ABackup(final String... a) {
     super(Perm.CREATE, false, a);
   }
 
