@@ -10,7 +10,7 @@ import org.basex.core.parse.Commands.CmdAlter;
 /**
  * Evaluates the 'alter user' command and alters the password of a user.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public final class AlterUser extends AUser {
@@ -28,8 +28,8 @@ public final class AlterUser extends AUser {
     final String user = args[0];
     final String pass = args[1];
     if(!Databases.validName(user)) return error(NAME_INVALID_X, user);
-    return !isMD5(pass) ? error(PW_NOT_VALID) : context.users.alter(user, pass) ?
-        info(PW_CHANGED_X, user) : error(UNKNOWN_USER_X, user);
+    return isMD5(pass) ? context.users.alter(user, pass) ? info(PW_CHANGED_X, user) :
+      error(UNKNOWN_USER_X, user) : error(PW_NOT_VALID);
   }
 
   @Override
