@@ -2,11 +2,10 @@ package org.basex.core.cmd;
 
 import static org.basex.core.Text.*;
 
-import java.io.*;
-
 import org.basex.core.*;
 import org.basex.core.parse.*;
-import org.basex.core.parse.Commands.*;
+import org.basex.core.parse.Commands.Cmd;
+import org.basex.core.parse.Commands.CmdRepo;
 import org.basex.query.*;
 import org.basex.query.util.pkg.*;
 import org.basex.util.*;
@@ -14,7 +13,7 @@ import org.basex.util.*;
 /**
  * Evaluates the 'repo delete' command.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Rositsa Shadura
  */
 public final class RepoDelete extends ARepo {
@@ -32,7 +31,7 @@ public final class RepoDelete extends ARepo {
   }
 
   @Override
-  protected boolean run() throws IOException {
+  protected boolean run() {
     try {
       new RepoManager(context, info).delete(args[0]);
       return info(PKG_DELETED_X, args[0]);
