@@ -8,16 +8,31 @@ import org.basex.query.*;
 /**
  * This is an interface for parsing database commands.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 abstract class CmdParser {
+  /** Input lines. */
+  final String input;
+  /** Context. */
+  final Context ctx;
+
   /** Suggest possible completions. */
-  protected boolean suggest;
+  boolean suggest;
   /** Single command flag. */
-  protected boolean single;
+  boolean single;
   /** Password reader. */
-  protected PasswordReader pwReader;
+  PasswordReader pwReader;
+
+  /**
+   * Constructor.
+   * @param input input
+   * @param context context
+   */
+  CmdParser(final String input, final Context context) {
+    ctx = context;
+    this.input = input;
+  }
 
   /**
    * Attaches a password reader.
