@@ -3,6 +3,7 @@ package org.basex.data;
 import static org.basex.util.Token.*;
 
 import java.util.*;
+import java.util.List;
 
 import org.basex.core.cmd.*;
 import org.basex.data.atomic.*;
@@ -62,7 +63,7 @@ import org.basex.util.list.*;
  * NOTE: the class is not thread-safe. It is imperative that all read/write accesses
  * are synchronized over a single context's read/write lock.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public abstract class Data {
@@ -127,7 +128,7 @@ public abstract class Data {
 
   /**
    * Starts an update operation: writes a file to disk to indicate that an update is
-   * going on, and exclusively locks the table.
+   * going on, and exclusively locks the table file.
    * @return success flag
    */
   public abstract boolean startUpdate();
@@ -147,12 +148,13 @@ public abstract class Data {
   }
 
   /**
-   * Returns the number of indexed pre references for the specified token.
+   * Returns a cost estimation for searching the specified token.
+   * Smaller values are better, a value of zero indicates that no results will be returned.
    * @param token text to be found
-   * @return number of hits
+   * @return cost estimation
    */
-  public final int count(final IndexToken token) {
-    return index(token.type()).count(token);
+  public final int costs(final IndexToken token) {
+    return index(token.type()).costs(token);
   }
 
   /**
@@ -177,7 +179,7 @@ public abstract class Data {
       case ATTRIBUTE: return atvindex;
       case FULLTEXT:  return ftxindex;
       case PATH:      return paths;
-      default:        throw Util.notexpected();
+      default:        throw Util.notExpected();
     }
   }
 
@@ -227,7 +229,7 @@ public abstract class Data {
    * @param id unique node id
    * @return pre value or -1 if id was not found
    */
-  final int preold(final int id) {
+  private int preold(final int id) {
     // find pre value in table
     for(int p = Math.max(0, id); p < meta.size; ++p)
       if(id == id(p)) return p;
@@ -398,7 +400,7 @@ public abstract class Data {
 
   /**
    * Returns all namespace keys and values.
-   * Should be only called for element nodes.
+   * Should only be called for element nodes.
    * @param pre pre value
    * @return key and value ids
    */
@@ -462,13 +464,11 @@ public abstract class Data {
    * @param name new tag, attribute or pi name
    * @param uri uri
    */
-  public final void update(final int pre, final int kind, final byte[] name,
-      final byte[] uri) {
-
+  public final void update(final int pre, final int kind, final byte[] name, final byte[] uri) {
     meta.update();
 
     if(kind == PI) {
-      updateText(pre, trim(concat(name, SPACE, atom(pre))), kind);
+      updateText(pre, trim(concat(name, SPACE, atom(pre))), PI);
     } else {
       // update/set namespace reference
       final int ouri = nspaces.uri(name, pre, this);
@@ -504,7 +504,8 @@ public abstract class Data {
   }
 
   /**
-   * Replaces parts of the database with the specified data instance.
+   * Rapid Replace implementation. Replaces parts of the database with the specified
+   * data instance.
    * @param tpre pre value of target node to be replaced
    * @param source clip with source data
    */
@@ -555,8 +556,8 @@ public abstract class Data {
         case ELEM:
           // add element
           byte[] nm = data.name(spre, kind);
-          elem(dist, tagindex.index(nm, null, false), data.attSize(spre, kind),
-              ssize, nspaces.uri(nm, true), false);
+          elem(dist, tagindex.index(nm, null, false), data.attSize(spre, kind), ssize,
+              nspaces.uri(nm, true), false);
           break;
         case TEXT:
         case COMM:
@@ -567,8 +568,8 @@ public abstract class Data {
         case ATTR:
           // add attribute
           nm = data.name(spre, kind);
-          attr(pre, dist, atnindex.index(nm, null, false),
-              data.text(spre, false), nspaces.uri(nm, false), false);
+          attr(pre, dist, atnindex.index(nm, null, false), data.text(spre, false),
+              nspaces.uri(nm, false), false);
           break;
       }
     }
@@ -604,7 +605,7 @@ public abstract class Data {
     if(data.kind(spre) == ATTR) {
       int d = 0;
       while(spre < source.end && data.kind(spre++) == ATTR) d++;
-      if(d > 1) attSize(tpar, kind(tpar), d + 1);
+      if(d > 1) attSize(tpar, kind(tpar), d + attSize(tpar, ELEM) - 1);
     }
   }
 
@@ -658,7 +659,7 @@ public abstract class Data {
 
     if(!cache) updateDist(pre, -s);
 
-    // propagate PRE value shifts to namespaces
+    // delete namespace nodes and propagate PRE value shifts
     nspaces.delete(pre, s, this);
   }
 
@@ -697,9 +698,10 @@ public abstract class Data {
 
     // loop through all entries
     final IntList preStack = new IntList();
-    final NSNode nsRoot = nspaces.current();
-    final HashSet<NSNode> newNodes = new HashSet<NSNode>();
+    final NSNode nsRoot = nspaces.getCurrent();
     final IntList flagPres = new IntList();
+    // track existing NSNodes - their PRE values have to be shifted after each tuple insertion
+    final List<NSNode> nsNodesShift = nspaces.getNSNodes(tpre);
 
     // indicates if database only contains a dummy node
     final Data data = source.data;
@@ -726,7 +728,7 @@ public abstract class Data {
       }
 
       // documents: use -1 as namespace root
-      final int nsPre = kind == Data.DOC ? -1 : pre - dist;
+      final int nsPre = kind == DOC ? -1 : pre - dist;
       if(c == 0) nspaces.root(nsPre, this);
       while(!preStack.isEmpty() && preStack.peek() > nsPre) nspaces.close(preStack.pop());
 
@@ -748,20 +750,14 @@ public abstract class Data {
               // see if prefix has been declared/ is part of current ns scope
               final byte[] old = nsScope.get(at.name(a));
               if(old == null || !eq(old, at.value(a))) {
-                // we have to keep track of all new NSNodes that are added
-                // to the Namespace structure, as their pre values must not
-                // be updated. I.e. if an NSNode N with pre value 3 existed
-                // prior to inserting and two new nodes are inserted at
-                // location pre == 3 we have to make sure N and only N gets
-                // updated.
-                newNodes.add(nspaces.add(at.name(a), at.value(a), pre));
+                nspaces.add(at.name(a), at.value(a), pre);
                 ne = true;
               }
             }
           }
           byte[] nm = data.name(spre, kind);
-          elem(dist, tagindex.index(nm, null, false), data.attSize(spre, kind),
-              ssize, nspaces.uri(nm, true), ne);
+          elem(dist, tagindex.index(nm, null, false), data.attSize(spre, kind), ssize,
+              nspaces.uri(nm, true), ne);
           preStack.push(pre);
           break;
         case TEXT:
@@ -775,23 +771,24 @@ public abstract class Data {
           nm = data.name(spre, kind);
           // check if prefix already in nsScope or not
           final byte[] attPref = prefix(nm);
-          // check if prefix of attribute has already been declared, otherwise
-          // add declaration to parent node
           if(data.nsFlag(spre) && nsScope.get(attPref) == null) {
-            nspaces.add(nsPre, preStack.isEmpty() ? -1 : preStack.peek(),
-                attPref, data.nspaces.uri(data.uri(spre, kind)), this);
+            // add declaration to parent node
+            nspaces.add(nsPre, preStack.isEmpty() ? -1 : preStack.peek(), attPref,
+            data.nspaces.uri(data.uri(spre, kind)), this);
             // save pre value to set ns flag later for this node. can't be done
             // here as direct table access would interfere with the buffer
             flagPres.add(nsPre);
           }
-          attr(pre, dist, atnindex.index(nm, null, false),
-              data.text(spre, false), nspaces.uri(nm, false), false);
+          attr(pre, dist, atnindex.index(nm, null, false), data.text(spre, false),
+              nspaces.uri(nm, false), false);
           break;
       }
+      // propagate PRE value shifts to keep namespace structure valid
+      Namespaces.incrementPre(nsNodesShift, 1);
     }
     // finalize and update namespace structure
     while(!preStack.isEmpty()) nspaces.close(preStack.pop());
-    nspaces.root(nsRoot);
+    nspaces.setCurrent(nsRoot);
 
     if(bp != 0) insert(tpre + c - 1 - (c - 1) % buf);
     // reset buffer to old size
@@ -818,9 +815,6 @@ public abstract class Data {
     }
 
     if(!cache) updateDist(tpre + size, size);
-
-    // propagate PRE value shifts to namespaces
-    if(tpar != -1) nspaces.insert(tpre, size, newNodes);
   }
 
   /**
@@ -925,7 +919,7 @@ public abstract class Data {
    * Sets the update buffer to a new size.
    * @param size number of table entries
    */
-  final void buffer(final int size) {
+  private void buffer(final int size) {
     final int bs = size << IO.NODEPOWER;
     if(b.length != bs) b = new byte[bs];
   }
@@ -954,8 +948,8 @@ public abstract class Data {
    * @param uri namespace uri reference
    * @param ne namespace flag
    */
-  public final void elem(final int dist, final int name, final int asize,
-      final int size, final int uri, final boolean ne) {
+  public final void elem(final int dist, final int name, final int asize, final int size,
+      final int uri, final boolean ne) {
 
     // build and insert new entry
     final int i = newID();
@@ -974,9 +968,7 @@ public abstract class Data {
    * @param value string value
    * @param kind node kind
    */
-  public final void text(final int pre, final int dist, final byte[] value,
-      final int kind) {
-
+  public final void text(final int pre, final int dist, final byte[] value, final int kind) {
     // build and insert new entry
     final int i = newID();
     final long v = index(pre, i, value, kind);
@@ -995,8 +987,8 @@ public abstract class Data {
    * @param uri namespace uri reference
    * @param ne namespace flag (only {@code true} if this is a stand-alone attribute)
    */
-  public final void attr(final int pre, final int dist, final int name,
-      final byte[] value, final int uri, final boolean ne) {
+  public final void attr(final int pre, final int dist, final int name, final byte[] value,
+      final int uri, final boolean ne) {
 
     // add attribute to text storage
     final int i = newID();
@@ -1051,8 +1043,7 @@ public abstract class Data {
    * @param kind node kind
    * @return reference
    */
-  protected abstract long index(final int pre, final int id, final byte[] value,
-      final int kind);
+  protected abstract long index(final int pre, final int id, final byte[] value, final int kind);
 
   /** Notify the index structures that an update operation is started. */
   void indexBegin() { }
@@ -1073,9 +1064,7 @@ public abstract class Data {
    * Indicates if this data instance is in main memory or on disk.
    * @return result of check
    */
-  public final boolean inMemory() {
-    return this instanceof MemData;
-  }
+  public abstract boolean inMemory();
 
   /**
    * Returns a string representation of the specified table range. Can be called
@@ -1084,7 +1073,7 @@ public abstract class Data {
    * @param end end pre value
    * @return table
    */
-  final String toString(final int start, final int end) {
+  private String toString(final int start, final int end) {
     return string(InfoStorage.table(this, start, end));
   }
 
