@@ -8,12 +8,12 @@ import org.basex.gui.layout.*;
  * This is the toolbar of the main window.
  * The toolbar contents are defined in {@link GUIConstants#TOOLBAR}.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
-public final class GUIToolBar extends JToolBar {
+final class GUIToolBar extends JToolBar {
   /** Toolbar commands. */
-  private final GUICmd[] cmd;
+  private final GUICommand[] cmd;
   /** Reference to main window. */
   private final GUI gui;
 
@@ -22,16 +22,16 @@ public final class GUIToolBar extends JToolBar {
    * @param tb toolbar commands
    * @param main reference to the main window
    */
-  public GUIToolBar(final GUICmd[] tb, final GUI main) {
+  GUIToolBar(final GUICommand[] tb, final GUI main) {
     setFloatable(false);
     cmd = tb;
     gui = main;
 
-    for(final GUICmd c : cmd) {
+    for(final GUICommand c : cmd) {
       if(c == null) {
         addSeparator();
       } else {
-        final BaseXButton button = BaseXButton.command(c, gui);
+        final AbstractButton button = BaseXButton.command(c, gui);
         button.setFocusable(false);
         add(button);
       }
@@ -43,7 +43,11 @@ public final class GUIToolBar extends JToolBar {
    */
   void refresh() {
     for(int b = 0; b < cmd.length; ++b) {
-      if(cmd[b] != null) cmd[b].refresh(gui, (BaseXButton) getComponent(b));
+      if(cmd[b] != null) {
+        final AbstractButton button = (AbstractButton) getComponent(b);
+        button.setEnabled(cmd[b].enabled(gui));
+        button.setSelected(cmd[b].selected(gui));
+      }
     }
   }
 }
