@@ -3,19 +3,19 @@ package org.basex.index.query;
 /**
  * This interface provides methods for returning index entries.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
-public abstract class EntryIterator {
+public interface EntryIterator {
   /**
    * Returns the next index entry.
    * @return entry
    */
-  public abstract byte[] next();
+  byte[] next();
 
   /**
    * Returns the number of occurrences of the current token.
    * @return counter
    */
-  public abstract int count();
+  int count();
 }
