@@ -4,7 +4,7 @@ package org.basex.query;
  * A runtime exception wrapping a {@link QueryException}, used for throwing those out of
  * methods whose interface doesn't allow it.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Leo Woerteler
  */
 public final class QueryRTException extends RuntimeException {
@@ -18,7 +18,7 @@ public final class QueryRTException extends RuntimeException {
   }
 
   @Override
-  public QueryException getCause() {
+  public synchronized QueryException getCause() {
     return (QueryException) super.getCause();
   }
 
