@@ -2,13 +2,13 @@ package org.basex.query;
 
 import static org.basex.util.Token.*;
 
-import org.basex.core.*;
+import org.basex.util.*;
 
 /**
  * This class assembles text string and tokens required by the XQuery processor
  * implementation.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public interface QueryText {
@@ -151,8 +151,6 @@ public interface QueryText {
   /** Parser token. */
   String ITEMM = "item";
   /** Parser token. */
-  String JSONSTR = "json";
-  /** Parser token. */
   String LANGUAGE = "language";
   /** Parser token. */
   String LAST = "last";
@@ -301,6 +299,8 @@ public interface QueryText {
   /** Parser token. */
   String UNORDERED = "unordered";
   /** Parser token. */
+  String UPDATE = "update";
+  /** Parser token. */
   String UPDATING = "updating";
   /** Parser token. */
   String UPPERCASE = "uppercase";
@@ -390,8 +390,6 @@ public interface QueryText {
   /** Parser token. */
   String CDATA = "<![CDATA[";
   /** Parser token. */
-  String COL = ":";
-  /** Parser token. */
   String COLS = "::";
   /** Parser token. */
   String COMMA = ",";
@@ -505,7 +503,7 @@ public interface QueryText {
   /** HTML token. */
   byte[] HTML = token("html");
   /** JSON token. */
-  byte[] JSON = token(JSONSTR);
+  byte[] JSON = token("json");
   /** MAP token. */
   byte[] MAP = token(MAPSTR);
   /** Package token. */
@@ -516,6 +514,8 @@ public interface QueryText {
   byte[] SQL = token("sql");
   /** SQL token. */
   byte[] STREAM = token("stream");
+  /** Binary token. */
+  byte[] BIN = token("bin");
   /** Cryptography token. */
   byte[] CRYPTO = token("crypto");
   /** Random token. */
@@ -540,7 +540,6 @@ public interface QueryText {
   /** Language attribute. */
   byte[] LANG = token("xml:lang");
 
-
   // URIS =====================================================================
 
   /** W3 URI. */
@@ -575,25 +574,27 @@ public interface QueryText {
 
   /** EXPath URI. */
   String EXPATH = "http://expath.org/ns/";
-  /** Cryptographic module URI. */
+  /** URI of Binary Module. */
+  byte[] BINURI = token(EXPATH + "binary");
+  /** URI of Cryptographic Module. */
   byte[] CRYPTOURI = token(EXPATH + "crypto");
-  /** File module URI. */
+  /** URI of File Module. */
   byte[] FILEURI = token(EXPATH + "file");
-  /** HTTP Client URI. */
+  /** URI of HTTP Client Module. */
   byte[] HTTPURI = token(EXPATH + "http-client");
-  /** Package API URI. */
+  /** URI of Package API. */
   byte[] PKGURI = token(EXPATH + "pkg");
-  /** ZIP URI.*/
+  /** URI of ZIP Module.*/
   byte[] ZIPURI = token(EXPATH + "zip");
-  /** EXPath Error URI. */
+  /** URI of EXPath errors. */
   byte[] EXPERROR = token(EXPATH + "error");
 
   /** Project URI. */
-  byte[] BASEXURI = token(Text.URL);
+  byte[] BASEXURI = token(Prop.URL);
   /** Project modules. */
-  String BXMODULES = Text.URL + "/modules/";
+  String BXMODULES = Prop.URL + "/modules/";
   /** Project errors. */
-  byte[] BXERRORS = token(Text.URL + "/errors");
+  byte[] BXERRORS = token(Prop.URL + "/errors");
 
   /** Database module URI. */
   byte[] ADMINURI = token(BXMODULES + "admin");
@@ -650,8 +651,8 @@ public interface QueryText {
 
   /** Java prefix. */
   byte[] JAVAPREF = token("java:");
-  /** Default collation. */
-  byte[] URLCOLL = concat(FNURI, token("/collation/codepoint"));
+  /** URI of default collation. */
+  byte[] COLLATIONURI = concat(FNURI, token("/collation/codepoint"));
 
   /** Supported documentation tags. */
   byte[][] DOC_TAGS = tokens("description", "author", "version", "param",
@@ -708,11 +709,11 @@ public interface QueryText {
   byte[] TEST = token("test");
   /** Minimum. */
   byte[] MIN = token("min");
-  /** Attribute name. */
+  /** Maximum. */
   byte[] MAX = token("max");
   /** Infinity. */
   byte[] INF = token("inf");
-  /** Infinity. */
+  /** Tailcall. */
   byte[] TCL = token("tailCall");
 
   /** Example for a Date format. */
@@ -755,7 +756,7 @@ public interface QueryText {
   /** Optimization info. */
   String OPTREMOVE = "%: removing %";
   /** Optimization info. */
-  String OPTTCE = "rewriting for tail calls: %";
+  String OPTTCE = "marking as tail call: %";
   /** Optimization info. */
   String OPTREMCTX = "removing context expression (.)";
   /** Optimization info. */
@@ -769,12 +770,8 @@ public interface QueryText {
   /** Optimization info. */
   String OPTFLWOR = "simplifying flwor expression";
   /** Optimization info. */
-  String OPTINLINEFN = "inlining function %";
-  /** Optimization info. */
   String OPTINLINE = "inlining %";
   /** Optimization info. */
-  String OPTWHERE = "rewriting where clause to predicate(s)";
-  /** Optimization info. */
   String OPTWHERE2 = "rewriting where clause(s)";
   /** Optimization info. */
   String OPTPRED = "rewriting % to predicate(s)";
@@ -799,9 +796,9 @@ public interface QueryText {
   /** Optimization info. */
   String OPTNOINDEX = "removing path with no index results";
   /** Optimization info. */
-  String OPTBIND = "binding static variable %";
-  /** Optimization info. */
   String OPTCHILD = "converting % to child steps";
+  /** Optimization info. */
+  String OPTUNROLL = "unrolling %";
 
   /** Warning. */
   String WARNSELF = "Warning: '%' will never yield results.";
