@@ -13,36 +13,37 @@ import org.basex.util.hash.*;
 /**
  * Document fragment.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
-public final class CDoc extends CFrag {
+public final class CDoc extends CNode {
   /**
    * Constructor.
+   * @param sctx static context
    * @param ii input info
    * @param e expression
    */
-  public CDoc(final InputInfo ii, final Expr e) {
-    super(ii, e);
+  public CDoc(final StaticContext sctx, final InputInfo ii, final Expr e) {
+    super(sctx, ii, e);
     type = SeqType.DOC_O;
   }
 
   @Override
   public FDoc item(final QueryContext ctx, final InputInfo ii) throws QueryException {
     // create node
-    final Constr c = new Constr(ii, ctx);
+    final Constr c = new Constr(ii, sc);
     final FDoc doc = new FDoc(c.children, Token.EMPTY);
 
     // add child nodes
-    c.add(expr);
-    if(c.errAtt || !c.atts.isEmpty()) DOCATTS.thrw(ii);
-    if(c.errNS || !c.nspaces.isEmpty()) DOCNS.thrw(ii);
+    c.add(ctx, expr);
+    if(c.errAtt || !c.atts.isEmpty()) throw DOCATTS.get(ii);
+    if(c.errNS || !c.nspaces.isEmpty()) throw DOCNS.get(ii);
     return doc.optimize();
   }
 
   @Override
   public Expr copy(final QueryContext ctx, final VarScope scp, final IntObjMap<Var> vs) {
-    return new CDoc(info, expr[0].copy(ctx, scp, vs));
+    return new CDoc(sc, info, expr[0].copy(ctx, scp, vs));
   }
 
   @Override
