@@ -15,18 +15,20 @@ import org.basex.util.hash.*;
 /**
  * Namespace constructor.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public final class CNSpace extends CName {
   /**
    * Constructor.
+   * @param sctx static context
    * @param ii input info
    * @param n name
    * @param v attribute values
    */
-  public CNSpace(final InputInfo ii, final Expr n, final Expr v) {
-    super(NSPACE, ii, n, v);
+  public CNSpace(final StaticContext sctx, final InputInfo ii, final Expr n,
+      final Expr v) {
+    super(NSPACE, sctx, ii, n, v);
     type = SeqType.NSP;
   }
 
@@ -34,18 +36,18 @@ public final class CNSpace extends CName {
   public FNames item(final QueryContext ctx, final InputInfo ii) throws QueryException {
     final Item it = name.item(ctx, info);
     final byte[] cp = checkEStr(it);
-    if(cp.length != 0 && !XMLToken.isNCName(cp)) INVNAME.thrw(info, expr[0]);
+    if(cp.length != 0 && !XMLToken.isNCName(cp)) throw INVNSNAME.get(info, cp);
 
     final byte[] cu = trim(value(ctx, ii));
-    if(eq(cp, XML) ^ eq(cu, XMLURI)) CNXML.thrw(info);
-    if(eq(cp, XMLNS)) CNINV.thrw(info, cp);
-    if(eq(cu, XMLNSURI) || cu.length == 0) CNINV.thrw(info, cu);
+    if(eq(cp, XML) ^ eq(cu, XMLURI)) throw CNXML.get(info);
+    if(eq(cp, XMLNS)) throw CNINV.get(info, cp);
+    if(eq(cu, XMLNSURI) || cu.length == 0) throw CNINV.get(info, cu);
 
     return new FNames(cp, cu);
   }
 
   @Override
   public Expr copy(final QueryContext ctx, final VarScope scp, final IntObjMap<Var> vs) {
-    return new CNSpace(info, name.copy(ctx, scp, vs), expr[0].copy(ctx, scp, vs));
+    return new CNSpace(sc, info, name.copy(ctx, scp, vs), expr[0].copy(ctx, scp, vs));
   }
 }
