@@ -5,7 +5,6 @@ import static org.basex.query.util.Err.*;
 import static org.basex.util.Token.*;
 
 import org.basex.core.*;
-import org.basex.data.*;
 import org.basex.query.*;
 import org.basex.query.func.*;
 import org.basex.query.iter.*;
@@ -22,16 +21,16 @@ import org.basex.util.*;
  * Abstract parse expression. All non-value expressions are derived from
  * this class.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public abstract class ParseExpr extends Expr {
   /** Input information. */
-  public InputInfo info;
-  /** Cardinality of result; unknown if set to -1. */
-  public long size = -1;
+  public final InputInfo info;
   /** Static type. */
   public SeqType type;
+  /** Cardinality of result; unknown if set to -1. */
+  protected long size = -1;
 
   /**
    * Constructor.
@@ -57,7 +56,7 @@ public abstract class ParseExpr extends Expr {
       final ValueBuilder vb = new ValueBuilder().add(it).add(n);
       n = ir.next();
       if(n != null) vb.add(Str.get("..."));
-      SEQCAST.thrw(ii, vb.value());
+      throw SEQCAST.get(ii, vb.value());
     }
     return it;
   }
@@ -84,9 +83,7 @@ public abstract class ParseExpr extends Expr {
   }
 
   @Override
-  public final Item ebv(final QueryContext ctx, final InputInfo ii)
-      throws QueryException {
-
+  public final Item ebv(final QueryContext ctx, final InputInfo ii) throws QueryException {
     final Item it;
     if(type().zeroOrOne()) {
       it = item(ctx, info);
@@ -94,15 +91,13 @@ public abstract class ParseExpr extends Expr {
       final Iter ir = iter(ctx);
       it = ir.next();
       if(!(it == null || it instanceof ANode || ir.next() == null))
-        CONDTYPE.thrw(info, this);
+        throw CONDTYPE.get(info, this);
     }
     return it == null ? Bln.FALSE : it;
   }
 
   @Override
-  public final Item test(final QueryContext ctx, final InputInfo ii)
-      throws QueryException {
-
+  public final Item test(final QueryContext ctx, final InputInfo ii) throws QueryException {
     final Item it = ebv(ctx, info);
     return (it instanceof ANum ? it.dbl(info) == ctx.pos : it.bool(info)) ? it : null;
   }
@@ -125,7 +120,7 @@ public abstract class ParseExpr extends Expr {
    * @return optimized expression
    * @throws QueryException query exception
    */
-  public final Expr preEval(final QueryContext ctx) throws QueryException {
+  protected final Expr preEval(final QueryContext ctx) throws QueryException {
     return optPre(item(ctx, info), ctx);
   }
 
@@ -148,8 +143,8 @@ public abstract class ParseExpr extends Expr {
    * @param ii input info
    * @return expression
    */
-  public static final Expr compBln(final Expr e, final InputInfo ii) {
-    return e.type().eq(SeqType.BLN) ? e : Function.BOOLEAN.get(ii, e);
+  protected static Expr compBln(final Expr e, final InputInfo ii) {
+    return e.type().eq(SeqType.BLN) ? e : Function.BOOLEAN.get(null, ii, e);
   }
 
   // VALIDITY CHECKS ==========================================================
@@ -157,37 +152,43 @@ public abstract class ParseExpr extends Expr {
   /**
    * Ensures that the specified expression performs no updates.
    * Otherwise, throws an exception.
-   * @param e expression (may be {@code null})
+   * @param expr expression (may be {@code null})
    * @throws QueryException query exception
    */
-  public void checkNoUp(final Expr e) throws QueryException {
-    if(e != null && e.has(Flag.UPD)) UPNOT.thrw(info, description());
+  protected void checkNoUp(final Expr expr) throws QueryException {
+    if(expr == null) return;
+    expr.checkUp();
+    if(expr.has(Flag.UPD)) throw UPNOT.get(info, description());
   }
 
   /**
    * Ensures that none of the specified expressions performs an update.
    * Otherwise, throws an exception.
-   * @param expr expressions (may contain {@code null} references)
+   * @param expr expressions (may be {@code null}, and may contain {@code null} references)
    * @throws QueryException query exception
    */
-  public final void checkNoneUp(final Expr... expr) throws QueryException {
-    if(expr != null) for(final Expr e : expr) checkNoUp(e);
+  protected final void checkNoneUp(final Expr... expr) throws QueryException {
+    if(expr == null) return;
+    checkAllUp(expr);
+    for(final Expr e : expr) {
+      if(e != null && e.has(Flag.UPD)) throw UPNOT.get(info, description());
+    }
   }
 
   /**
-   * Ensures that all specified expressions are either updating and vacuous or
-   * non-updating. Otherwise, throws an exception.
+   * Ensures that all specified expressions are vacuous or either updating or non-updating.
+   * Otherwise, throws an exception.
    * @param expr expressions to be checked
    * @throws QueryException query exception
    */
-  public void checkAllUp(final Expr... expr) throws QueryException {
+  void checkAllUp(final Expr... expr) throws QueryException {
     // updating state: 0 = initial state, 1 = updating, -1 = non-updating
     int s = 0;
     for(final Expr e : expr) {
       e.checkUp();
       if(e.isVacuous()) continue;
       final boolean u = e.has(Flag.UPD);
-      if(u && s == -1 || !u && s == 1) UPALL.thrw(info, description());
+      if(u && s == -1 || !u && s == 1) throw UPALL.get(info, description());
       s = u ? 1 : -1;
     }
   }
@@ -200,13 +201,11 @@ public abstract class ParseExpr extends Expr {
    * @return boolean
    * @throws QueryException query exception
    */
-  public final boolean checkBln(final Expr e, final QueryContext ctx)
-      throws QueryException {
-
+  protected final boolean checkBln(final Expr e, final QueryContext ctx) throws QueryException {
     final Item it = checkNoEmpty(e.item(ctx, info), AtomType.BLN);
     final Type ip = it.type;
     if(ip == AtomType.BLN || ip.isUntyped()) return it.bool(info);
-    throw Err.INVCAST.thrw(info, it.type, AtomType.BLN);
+    throw INVCAST.get(info, it.type, AtomType.BLN);
   }
 
   /**
@@ -217,12 +216,24 @@ public abstract class ParseExpr extends Expr {
    * @return double
    * @throws QueryException query exception
    */
-  public final double checkDbl(final Expr e, final QueryContext ctx)
-      throws QueryException {
-
+  protected final double checkDbl(final Expr e, final QueryContext ctx) throws QueryException {
     final Item it = checkNoEmpty(e.item(ctx, info), AtomType.DBL);
     if(it.type.isNumberOrUntyped()) return it.dbl(info);
-    throw number(this, it);
+    throw numberError(this, it);
+  }
+
+  /**
+   * Checks if the specified expression yields a float.
+   * Returns the float or throws an exception.
+   * @param e expression to be checked
+   * @param ctx query context
+   * @return double
+   * @throws QueryException query exception
+   */
+  protected final float checkFlt(final Expr e, final QueryContext ctx) throws QueryException {
+    final Item it = checkNoEmpty(e.item(ctx, info), AtomType.FLT);
+    if(it.type.isNumberOrUntyped()) return it.flt(info);
+    throw numberError(this, it);
   }
 
   /**
@@ -233,7 +244,7 @@ public abstract class ParseExpr extends Expr {
    * @return integer value
    * @throws QueryException query exception
    */
-  public final long checkItr(final Expr e, final QueryContext ctx) throws QueryException {
+  protected final long checkItr(final Expr e, final QueryContext ctx) throws QueryException {
     return checkItr(checkNoEmpty(e.item(ctx, info), AtomType.ITR));
   }
 
@@ -244,10 +255,10 @@ public abstract class ParseExpr extends Expr {
    * @return item
    * @throws QueryException query exception
    */
-  public final long checkItr(final Item it) throws QueryException {
+  protected final long checkItr(final Item it) throws QueryException {
     final Type ip = it.type;
     if(ip.instanceOf(AtomType.ITR) || ip.isUntyped()) return it.itr(info);
-    throw Err.INVCAST.thrw(info, it.type, AtomType.ITR);
+    throw INVCAST.get(info, it.type, AtomType.ITR);
   }
 
   /**
@@ -258,8 +269,7 @@ public abstract class ParseExpr extends Expr {
    * @return boolean
    * @throws QueryException query exception
    */
-  public final ANode checkNode(final Expr e, final QueryContext ctx)
-      throws QueryException {
+  protected final ANode checkNode(final Expr e, final QueryContext ctx) throws QueryException {
     return checkNode(checkItem(e, ctx));
   }
 
@@ -270,9 +280,9 @@ public abstract class ParseExpr extends Expr {
    * @return item
    * @throws QueryException query exception
    */
-  public final ANode checkNode(final Item it) throws QueryException {
+  protected final ANode checkNode(final Item it) throws QueryException {
     if(it instanceof ANode) return (ANode) it;
-    throw Err.INVCAST.thrw(info, it.type, NodeType.NOD);
+    throw INVCAST.get(info, it.type, NodeType.NOD);
   }
 
   /**
@@ -282,21 +292,22 @@ public abstract class ParseExpr extends Expr {
    * @return item
    * @throws QueryException query exception
    */
-  public final DBNode checkDBNode(final Item it) throws QueryException {
+  protected final DBNode checkDBNode(final Item it) throws QueryException {
     if(it instanceof DBNode) return (DBNode) it;
-    throw BXDB_NODB.thrw(info, this);
+    throw BXDB_NODB.get(info, this);
   }
 
   /**
    * Checks if the specified collation is supported.
    * @param e expression to be checked
    * @param ctx query context
+   * @param sc static context
    * @return collator, or {@code null} (default collation)
    * @throws QueryException query exception
    */
-  public final Collation checkColl(final Expr e, final QueryContext ctx)
+  protected final Collation checkColl(final Expr e, final QueryContext ctx, final StaticContext sc)
       throws QueryException {
-    return Collation.get(e == null ? null : checkStr(e, ctx), ctx, info, WHICHCOLL);
+    return Collation.get(e == null ? null : checkStr(e, ctx), ctx, sc, info, WHICHCOLL);
   }
 
   /**
@@ -307,8 +318,7 @@ public abstract class ParseExpr extends Expr {
    * @return string representation
    * @throws QueryException query exception
    */
-  public final byte[] checkStr(final Expr e, final QueryContext ctx)
-      throws QueryException {
+  protected final byte[] checkStr(final Expr e, final QueryContext ctx) throws QueryException {
     return checkStr(checkItem(e, ctx));
   }
 
@@ -319,10 +329,10 @@ public abstract class ParseExpr extends Expr {
    * @return string representation
    * @throws QueryException query exception
    */
-  public final byte[] checkStr(final Item it) throws QueryException {
+  protected final byte[] checkStr(final Item it) throws QueryException {
     final Type ip = it.type;
     if(ip.isStringOrUntyped()) return it.string(info);
-    throw Err.INVCAST.thrw(info, it.type, AtomType.STR);
+    throw INVCAST.get(info, it.type, AtomType.STR);
   }
 
   /**
@@ -332,12 +342,11 @@ public abstract class ParseExpr extends Expr {
    * @return string representation
    * @throws QueryException query exception
    */
-  public final byte[] checkEStr(final Item it) throws QueryException {
+  protected final byte[] checkEStr(final Item it) throws QueryException {
     if(it == null) return EMPTY;
     final Type ip = it.type;
     if(ip.isStringOrUntyped()) return it.string(info);
-    if(it instanceof FItem) FIATOM.thrw(info, this);
-    throw Err.INVCAST.thrw(info, it.type, AtomType.STR);
+    throw it instanceof FItem ? FIATOM.get(info, ip) : INVCAST.get(info, it.type, AtomType.STR);
   }
 
   /**
@@ -346,10 +355,10 @@ public abstract class ParseExpr extends Expr {
    * @return context
    * @throws QueryException query exception
    */
-  public final Value checkCtx(final QueryContext ctx) throws QueryException {
+  protected final Value checkCtx(final QueryContext ctx) throws QueryException {
     final Value v = ctx.value;
     if(v != null) return v;
-    throw NOCTX.thrw(info, this);
+    throw NOCTX.get(info, this);
   }
 
   /**
@@ -358,11 +367,11 @@ public abstract class ParseExpr extends Expr {
    * @return context
    * @throws QueryException query exception
    */
-  public final ANode checkNode(final QueryContext ctx) throws QueryException {
+  protected final ANode checkNode(final QueryContext ctx) throws QueryException {
     final Value v = ctx.value;
-    if(v == null) NOCTX.thrw(info, this);
-    if(!(v instanceof ANode)) STEPNODE.thrw(info, this, v.type);
-    return (ANode) v;
+    if(v == null) throw NOCTX.get(info, this);
+    if(v instanceof ANode) return (ANode) v;
+    throw STEPNODE.get(info, this, v.type);
   }
 
   /**
@@ -372,8 +381,7 @@ public abstract class ParseExpr extends Expr {
    * @return item
    * @throws QueryException query exception
    */
-  public final Item checkItem(final Expr e, final QueryContext ctx)
-      throws QueryException {
+  protected final Item checkItem(final Expr e, final QueryContext ctx) throws QueryException {
     return checkNoEmpty(e.item(ctx, info));
   }
 
@@ -384,12 +392,10 @@ public abstract class ParseExpr extends Expr {
    * @return binary item
    * @throws QueryException query exception
    */
-  public final Bin checkBinary(final Expr e, final QueryContext ctx)
-      throws QueryException {
-
+  protected final Bin checkBinary(final Expr e, final QueryContext ctx) throws QueryException {
     final Item it = checkItem(e, ctx);
     if(it instanceof Bin) return (Bin) it;
-    throw BINARYTYPE.thrw(info, it.type);
+    throw BINARYTYPE.get(info, it.type);
   }
 
   /**
@@ -398,27 +404,27 @@ public abstract class ParseExpr extends Expr {
    * @return byte representation
    * @throws QueryException query exception
    */
-  public final byte[] checkStrBin(final Item it) throws QueryException {
+  protected final byte[] checkStrBin(final Item it) throws QueryException {
     if(it instanceof AStr) return it.string(info);
     if(it instanceof Bin) return ((Bin) it).binary(info);
-    throw STRBINTYPE.thrw(info, it.type);
+    throw STRBINTYPE.get(info, it.type);
   }
 
   /**
-   * Checks if the specified expression has the specified type; if no, throws
-   * an exception.
+   * Checks if the specified expression has the specified type; if no, throws an exception.
    * @param e expression to be checked
    * @param ctx query context
+   * @param sc static context
    * @return specified item
    * @throws QueryException query exception
    */
-  public final QNm checkQNm(final Expr e, final QueryContext ctx)
+  protected final QNm checkQNm(final Expr e, final QueryContext ctx, final StaticContext sc)
       throws QueryException {
 
     final Item it = checkItem(e, ctx);
     if(it.type == AtomType.QNM) return (QNm) it;
-    if(it.type.isUntyped() && ctx.sc.xquery3()) NSSENS.thrw(info, it.type, AtomType.QNM);
-    throw Err.INVCAST.thrw(info, it.type, AtomType.QNM);
+    if(it.type.isUntyped() && sc.xquery3()) throw NSSENS.get(info, it.type, AtomType.QNM);
+    throw INVCAST.get(info, it.type, AtomType.QNM);
   }
 
   /**
@@ -429,8 +435,7 @@ public abstract class ParseExpr extends Expr {
    * @return function item
    * @throws QueryException query exception
    */
-  public FItem checkFunc(final Expr e, final QueryContext ctx)
-      throws QueryException {
+  protected FItem checkFunc(final Expr e, final QueryContext ctx) throws QueryException {
     return (FItem) checkType(checkItem(e, ctx), FuncType.ANY_FUN);
   }
 
@@ -442,9 +447,9 @@ public abstract class ParseExpr extends Expr {
    * @return specified item
    * @throws QueryException query exception
    */
-  public final Item checkType(final Item it, final Type t) throws QueryException {
+  protected final Item checkType(final Item it, final Type t) throws QueryException {
     if(checkNoEmpty(it, t).type.instanceOf(t)) return it;
-    throw Err.INVCAST.thrw(info, it.type, t);
+    throw INVCAST.get(info, it.type, t);
   }
 
   /**
@@ -453,9 +458,9 @@ public abstract class ParseExpr extends Expr {
    * @return specified item
    * @throws QueryException query exception
    */
-  public final Item checkNoEmpty(final Item it) throws QueryException {
+  protected final Item checkNoEmpty(final Item it) throws QueryException {
     if(it != null) return it;
-    throw INVEMPTY.thrw(info, description());
+    throw INVEMPTY.get(info, description());
   }
 
   /**
@@ -467,7 +472,7 @@ public abstract class ParseExpr extends Expr {
    */
   private Item checkNoEmpty(final Item it, final Type t) throws QueryException {
     if(it != null) return it;
-    throw INVEMPTYEX.thrw(info, description(), t);
+    throw INVEMPTYEX.get(info, description(), t);
   }
 
   /**
@@ -478,8 +483,7 @@ public abstract class ParseExpr extends Expr {
    * @return item
    * @throws QueryException query exception
    */
-  public final byte[] checkEStr(final Expr e, final QueryContext ctx)
-      throws QueryException {
+  protected final byte[] checkEStr(final Expr e, final QueryContext ctx) throws QueryException {
     return checkEStr(e.item(ctx, info));
   }
 
@@ -489,7 +493,7 @@ public abstract class ParseExpr extends Expr {
    * @param ctx query context
    * @throws QueryException query exception
    */
-  public final void checkAdmin(final QueryContext ctx) throws QueryException {
+  protected final void checkAdmin(final QueryContext ctx) throws QueryException {
     checkPerm(ctx, Perm.ADMIN);
   }
 
@@ -499,25 +503,10 @@ public abstract class ParseExpr extends Expr {
    * @param ctx query context
    * @throws QueryException query exception
    */
-  public final void checkCreate(final QueryContext ctx) throws QueryException {
+  protected final void checkCreate(final QueryContext ctx) throws QueryException {
     checkPerm(ctx, Perm.CREATE);
   }
 
-  /**
-   * Checks if the current user has write permissions for the specified database.
-   * If negative, an exception is thrown.
-   * @param data data reference
-   * @param ctx query context
-   * @return data reference
-   * @throws QueryException query exception
-   */
-  public final Data checkWrite(final Data data, final QueryContext ctx)
-      throws QueryException {
-
-    if(!ctx.context.perm(Perm.WRITE, data.meta)) BASX_PERM.thrw(info, Perm.WRITE);
-    return data;
-  }
-
   /**
    * Checks if the current user has given permissions. If negative, an
    * exception is thrown.
@@ -526,7 +515,7 @@ public abstract class ParseExpr extends Expr {
    * @throws QueryException query exception
    */
   private void checkPerm(final QueryContext ctx, final Perm p) throws QueryException {
-    if(!ctx.context.user.has(p)) throw BASX_PERM.thrw(info, p);
+    if(!ctx.context.user.has(p)) throw BASX_PERM.get(info, p);
   }
 
   /**
@@ -535,8 +524,8 @@ public abstract class ParseExpr extends Expr {
    * @return the map
    * @throws QueryException if the item is not a map
    */
-  public Map checkMap(final Item it) throws QueryException {
+  protected Map checkMap(final Item it) throws QueryException {
     if(it instanceof Map) return (Map) it;
-    throw Err.INVCAST.thrw(info, it.type, SeqType.ANY_MAP);
+    throw INVCAST.get(info, it.type, SeqType.ANY_MAP);
   }
 }
