@@ -11,7 +11,7 @@ import org.basex.util.hash.*;
 /**
  * Map ("bang") operator. Only occurs as argument of the {@link MixedPath} expression.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public final class Bang extends Single {
@@ -46,6 +46,21 @@ public final class Bang extends Single {
     return new Bang(info, expr.copy(ctx, scp, vs));
   }
 
+  @Override
+  public boolean isVacuous() {
+    return expr.isVacuous();
+  }
+
+  @Override
+  public void checkUp() throws QueryException {
+    expr.checkUp();
+  }
+
+  @Override
+  public String description() {
+    return "Map operator";
+  }
+
   @Override
   public String toString() {
     return expr.toString();
