@@ -7,7 +7,7 @@ import org.basex.util.*;
 /**
  * Simple node kind test.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 class KindTest extends Test {
@@ -38,11 +38,13 @@ class KindTest extends Test {
   public Test intersect(final Test other) {
     if(other instanceof NodeTest || other instanceof DocTest) {
       return other.type.instanceOf(type) ? other : null;
-    } else if(other instanceof KindTest) {
+    }
+    if(other instanceof KindTest) {
       return type.instanceOf(other.type) ? this :
         other.type.instanceOf(type) ? other : null;
-    } else if(other instanceof NameTest || other instanceof InvDocTest) {
-      throw Util.notexpected(other);
+    }
+    if(other instanceof NameTest || other instanceof InvDocTest) {
+      throw Util.notExpected(other);
     }
     return null;
   }
