@@ -16,24 +16,25 @@ import org.basex.util.hash.*;
 /**
  * Delete expression.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Lukas Kircher
  */
 public final class Delete extends Update {
   /**
    * Constructor.
-   * @param ii input info
-   * @param r return expression
+   * @param sctx static context
+   * @param info input info
+   * @param expr return expression
    */
-  public Delete(final InputInfo ii, final Expr r) {
-    super(ii, r);
+  public Delete(final StaticContext sctx, final InputInfo info, final Expr expr) {
+    super(sctx, info, expr);
   }
 
   @Override
   public Item item(final QueryContext ctx, final InputInfo ii) throws QueryException {
     final Iter t = ctx.iter(expr[0]);
     for(Item i; (i = t.next()) != null;) {
-      if(!(i instanceof ANode)) UPTRGDELEMPT.thrw(info);
+      if(!(i instanceof ANode)) throw UPTRGDELEMPT.get(info);
       final ANode n = (ANode) i;
       // nodes without parents are ignored
       if(n.parent() == null) continue;
@@ -45,7 +46,7 @@ public final class Delete extends Update {
 
   @Override
   public Expr copy(final QueryContext ctx, final VarScope scp, final IntObjMap<Var> vs) {
-    return new Delete(info, expr[0].copy(ctx, scp, vs));
+    return new Delete(sc, info, expr[0].copy(ctx, scp, vs));
   }
 
   @Override
