@@ -2,7 +2,6 @@ package org.basex.query.up.primitives;
 
 import org.basex.data.*;
 import org.basex.data.atomic.*;
-import org.basex.query.*;
 import org.basex.query.up.*;
 import org.basex.query.util.*;
 import org.basex.query.value.node.*;
@@ -11,7 +10,7 @@ import org.basex.util.*;
 /**
  * Insert after primitive.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Lukas Kircher
  */
 public final class InsertAfter extends NodeCopy {
@@ -23,25 +22,25 @@ public final class InsertAfter extends NodeCopy {
    * @param c node copy insertion sequence
    */
   public InsertAfter(final int p, final Data d, final InputInfo i, final ANodeList c) {
-    super(PrimitiveType.INSERTAFTER, p, d, i, c);
+    super(UpdateType.INSERTAFTER, p, d, i, c);
   }
 
   @Override
-  public void merge(final UpdatePrimitive p) throws QueryException {
-    final ANodeList newInsert = ((InsertAfter) p).insert;
+  public void merge(final Update p) {
+    final ANodeList newInsert = ((NodeCopy) p).insert;
     for(final ANode n : newInsert) insert.add(n);
   }
 
   @Override
-  public void addAtomics(final AtomicUpdateList l) {
-    final int k = data.kind(targetPre);
-    final int s = data.size(targetPre, k);
-    l.addInsert(targetPre + s, data.parent(targetPre, k), insseq, false);
+  public void addAtomics(final AtomicUpdateCache l) {
+    final int k = data.kind(pre);
+    final int s = data.size(pre, k);
+    l.addInsert(pre + s, data.parent(pre, k), insseq, false);
   }
 
   @Override
-  public UpdatePrimitive[] substitute(final MemData tmp) {
-    return new UpdatePrimitive[] { this };
+  public NodeUpdate[] substitute(final MemData tmp) {
+    return new NodeUpdate[] { this };
   }
 
   @Override
