@@ -10,7 +10,7 @@ import org.basex.util.*;
 /**
  * Insert into primitive.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Lukas Kircher
  */
 public class InsertInto extends NodeCopy {
@@ -22,24 +22,24 @@ public class InsertInto extends NodeCopy {
    * @param n node copy insertion sequence
    */
   public InsertInto(final int p, final Data d, final InputInfo i, final ANodeList n) {
-    super(PrimitiveType.INSERTINTO, p, d, i, n);
+    super(UpdateType.INSERTINTO, p, d, i, n);
   }
 
   @Override
-  public final void merge(final UpdatePrimitive p) {
-    final ANodeList newInsert = ((NodeCopy) p).insert;
+  public final void merge(final Update up) {
+    final ANodeList newInsert = ((NodeCopy) up).insert;
     for(final ANode n : newInsert) insert.add(n);
   }
 
   @Override
-  public final void addAtomics(final AtomicUpdateList l) {
-    final int s = data.size(targetPre, data.kind(targetPre));
-    l.addInsert(targetPre + s, targetPre, insseq, false);
+  public final void addAtomics(final AtomicUpdateCache l) {
+    final int s = data.size(pre, data.kind(pre));
+    l.addInsert(pre + s, pre, insseq, false);
   }
 
   @Override
-  public final UpdatePrimitive[] substitute(final MemData tmp) {
-    return new UpdatePrimitive[] { this };
+  public final NodeUpdate[] substitute(final MemData tmp) {
+    return new NodeUpdate[] { this };
   }
 
   @Override
