@@ -2,7 +2,6 @@ package org.basex.query.util;
 
 import java.io.*;
 
-import org.basex.core.*;
 import org.basex.query.value.item.*;
 import org.basex.server.*;
 import org.basex.util.*;
@@ -11,7 +10,7 @@ import org.basex.util.hash.*;
 /**
  * Opened database client sessions.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public final class ClientSessions {
@@ -26,7 +25,7 @@ public final class ClientSessions {
    * @return session id
    */
   public Uri add(final ClientSession cs) {
-    final byte[] uri = Token.token(Text.NAMELC + "://" + cs + '/' + ++lastId);
+    final byte[] uri = Token.token(Prop.PROJECT_NAME + "://" + cs + '/' + ++lastId);
     conns.put(uri, cs);
     return Uri.uri(uri);
   }
