@@ -12,7 +12,7 @@ import org.basex.util.*;
 /**
  * Streamable base64 item ({@code xs:base64Binary}).
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public final class B64Stream extends B64 {
@@ -36,7 +36,7 @@ public final class B64Stream extends B64 {
     try {
       return input.read();
     } catch(final IOException ex) {
-      throw error.thrw(ii, ex);
+      throw error.get(ii, ex);
     }
   }
 
@@ -45,7 +45,7 @@ public final class B64Stream extends B64 {
     try {
       return new BufferInput(input);
     } catch(final IOException ex) {
-      throw error.thrw(ii, ex);
+      throw error.get(ii, ex);
     }
   }
 
