@@ -9,12 +9,12 @@ import org.basex.util.*;
 /**
  * Abstract class for binary items.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public abstract class Bin extends Item {
   /** Binary data. */
-  byte[] data;
+  final byte[] data;
 
   /**
    * Constructor.
