@@ -11,7 +11,7 @@ import org.w3c.dom.*;
 /**
  * Comment node fragment.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public final class FComm extends FNode {
@@ -62,7 +62,7 @@ public final class FComm extends FNode {
    * @throws QueryException query exception
    */
   public static byte[] parse(final byte[] str, final InputInfo ii) throws QueryException {
-    if(contains(str, DASHES) || endsWith(str, '-')) COMINVALID.thrw(ii, str);
+    if(contains(str, DASHES) || endsWith(str, '-')) throw COMINVALID.get(ii, str);
     return str;
   }
 }
