@@ -1,7 +1,5 @@
 package org.basex.query.var;
 
-import java.util.*;
-
 import org.basex.query.value.item.*;
 import org.basex.util.*;
 import org.basex.util.list.*;
@@ -9,13 +7,13 @@ import org.basex.util.list.*;
 /**
  * Variable stack.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  * @author Leo Woerteler
  */
 public final class VarStack extends ElementList {
   /** Variable expressions. */
-  public Var[] vars;
+  private Var[] vars;
 
   /**
    * Default constructor.
@@ -51,10 +49,4 @@ public final class VarStack extends ElementList {
     for(int i = size; i-- > 0;) if(name.eq(vars[i].name)) return vars[i];
     return null;
   }
-
-  /** Empties this stack. */
-  public void clear() {
-    Arrays.fill(vars, null);
-    size = 0;
-  }
 }
