@@ -5,12 +5,10 @@ import java.util.*;
 /**
  * Abstract class for stemmer and tokenizer implementations.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Jens Erat
  */
-abstract class LanguageImpl extends FTIterator
-    implements Comparable<LanguageImpl> {
-
+abstract class LanguageImpl extends FTIterator implements Comparable<LanguageImpl> {
   /**
    * Returns the precedence of the processor. If two language implementations
    * support the same language, the processor with the higher precedence
