@@ -6,12 +6,12 @@ import org.basex.util.*;
  * This is an abstract class for storing elements of any kind in an array-based
  * list.
  *
- * @author BaseX Team 2005-13, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public abstract class ElementList {
   /** Resize factor for extending the arrays. */
-  protected double factor = Array.RESIZE;
+  double factor = Array.RESIZE;
   /** Number of elements. */
   protected int size;
 
