@@ -2,13 +2,12 @@ package org.basex.examples.module;
 
 import org.basex.query.*;
 import org.basex.query.value.item.*;
-import org.basex.util.*;
 
 /**
  * This is a simple demo module called by {link {@link FruitsExample}.
  * It is derived from the {@link QueryModule} class.
  *
- * @author BaseX Team 2005-12, BSD License
+ * @author BaseX Team 2005-14, BSD License
  */
 public class FruitsModule extends QueryModule {
   /** Fruits array. */
@@ -45,10 +44,10 @@ public class FruitsModule extends QueryModule {
   }
 
   /**
-   * Context-aware function: returns the default function namespace of this query.
-   * @return function namespace
+   * Context function: returns the name of the current user.
+   * @return user
    */
-  public String functionNamespace() {
-    return Token.string(context.sc.funcNS);
+  public String user() {
+    return queryContext.context.user.name;
   }
 }
