@@ -10,7 +10,7 @@ import org.basex.util.*;
 /**
  * Wrapper for representing an empty sequence.
  *
- * @author BaseX Team 2005-13, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public final class XdmEmpty extends XdmValue {
@@ -47,7 +47,7 @@ public final class XdmEmpty extends XdmValue {
 
       @Override
       public void remove() {
-        Util.notexpected();
+        throw Util.notExpected();
       }
     };
   }
