@@ -10,7 +10,7 @@ import org.basex.util.*;
 /**
  * Wrapper for representing XQuery values.
  *
- * @author BaseX Team 2005-13, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 final class XdmSequence extends XdmValue {
@@ -52,7 +52,7 @@ final class XdmSequence extends XdmValue {
 
       @Override
       public void remove() {
-        Util.notexpected();
+        throw Util.notExpected();
       }
     };
   }
