@@ -7,6 +7,7 @@ import java.io.*;
 import java.util.*;
 import java.util.regex.*;
 
+import org.basex.build.*;
 import org.basex.core.*;
 import org.basex.core.Context;
 import org.basex.core.cmd.*;
@@ -28,10 +29,10 @@ import org.basex.util.list.*;
 /**
  * XQuery Test Suite wrapper.
  *
- * @author BaseX Team 2005-13, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
-public abstract class W3CTS {
+public abstract class W3CTS extends Main {
   // Try "ulimit -n 65536" if Linux tells you "Too many open files."
 
   /** Inspect flag. */
@@ -115,24 +116,25 @@ public abstract class W3CTS {
 
   /**
    * Constructor.
+   * @param args command-line arguments
    * @param nm name of test
    */
-  protected W3CTS(final String nm) {
+  protected W3CTS(final String[] args, final String nm) {
+    super(args);
     input = nm + "Catalog" + IO.XMLSUFFIX;
     testid = nm.substring(0, 4);
     pathlog = testid.toLowerCase(Locale.ENGLISH) + ".log";
-    context.mprop.set(MainProp.DBPATH, sandbox().path() + "/data");
+    context.globalopts.set(GlobalOptions.DBPATH, sandbox().path() + "/data");
   }
 
   /**
    * Runs the test suite.
-   * @param args command-line arguments
    * @throws QueryException query exception
    * @throws IOException I/O exception
    */
-  void run(final String[] args) throws QueryException, IOException {
+  void run() throws QueryException, IOException {
     try {
-      parseArguments(args);
+      parseArgs();
     } catch(final IOException ex) {
       Util.errln(ex);
       System.exit(1);
@@ -147,13 +149,12 @@ public abstract class W3CTS {
     final String sources = path + "TestSources/";
 
     final Performance perf = new Performance();
-    context.prop.set(Prop.CHOP, false);
+    context.options.set(MainOptions.CHOP, false);
 
-    //new Check(path + input).execute(context);
-    data = CreateDB.mainMem(new IOFile(path + input), context);
+    data = MemBuilder.build(new IOFile(path + input), context);
 
     final Nodes root = new Nodes(0, data);
-    Util.outln(NL + Util.name(this) + " Test Suite " +
+    Util.outln(NL + Util.className(this) + " Test Suite " +
         text("/*:test-suite/@version", root));
 
     Util.outln("Caching Sources...");
@@ -276,7 +277,7 @@ public abstract class W3CTS {
 
       final String inname = text("*:query/@name", state);
       final IOFile query = new IOFile(queries + pth + inname + IO.XQSUFFIX);
-      context.prop.set(Prop.QUERYPATH, query.path());
+      context.options.set(MainOptions.QUERYPATH, query.path());
       final String in = read(query);
       String er = null;
       ValueBuilder iter = null;
@@ -285,14 +286,14 @@ public abstract class W3CTS {
       Nodes curr = null;
       if(cont.size() != 0) {
         final String p = srcs.get(string(data.atom(cont.pres[0])));
-        final Data d = CreateDB.mainMem(IO.get(p), context);
+        final Data d = MemBuilder.build(IO.get(p), context);
         curr = new Nodes(d.resources.docs().toArray(), d);
         curr.root = true;
       }
 
-      context.prop.set(Prop.QUERYINFO, compile);
+      context.options.set(MainOptions.QUERYINFO, compile);
       final QueryProcessor xq = new QueryProcessor(in, context).context(curr);
-      context.prop.set(Prop.QUERYINFO, false);
+      context.options.set(MainOptions.QUERYINFO, false);
 
       final ArrayOutput ao = new ArrayOutput();
       final TokenBuilder files = new TokenBuilder();
@@ -317,8 +318,8 @@ public abstract class W3CTS {
         iter = xq.value().cache();
 
         // serialize query
-        final SerializerProp sp = new SerializerProp();
-        sp.set(SerializerProp.S_INDENT, NO);
+        final SerializerOptions sp = new SerializerOptions();
+        sp.set(SerializerOptions.INDENT, NO);
         final Serializer ser = Serializer.get(ao, sp);
         for(Item it; (it = iter.next()) != null;) ser.serialize(it);
         ser.close();
@@ -514,7 +515,7 @@ public abstract class W3CTS {
   private ValueIter toIter(final String xml, final boolean frag) {
     try {
       final String str = frag ? "<X>" + xml + "</X>" : xml;
-      final Data d = CreateDB.mainMem(IO.get(str), context);
+      final Data d = MemBuilder.build(IO.get(str), context);
       final IntList il = new IntList();
       for(int p = frag ? 2 : 0; p < d.meta.size; p += d.size(p, d.kind(p))) {
         il.add(p);
@@ -571,7 +572,7 @@ public abstract class W3CTS {
             src = dbname;
           }
         }
-        expr = def.get(Str.get(src));
+        expr = def.get(qp.sc, Str.get(src));
       }
       if(var != null) qp.bind(string(data.atom(var.pres[c])), expr);
     }
@@ -604,13 +605,12 @@ public abstract class W3CTS {
    * @throws QueryException query exception
    */
   private Uri coll(final byte[] name, final QueryProcessor qp) throws QueryException {
-    qp.ctx.resource.addCollection(string(name), colls.get(string(name)));
+    qp.ctx.resource.addCollection(string(name), colls.get(string(name)), qp.sc.baseIO());
     return Uri.uri(name);
   }
 
   /**
-   * Evaluates the the input files and assigns the result to the specified
-   * variables.
+   * Evaluates the the input files and assigns the result to the specified variables.
    * @param nod variables
    * @param var documents
    * @param pth file path
@@ -637,8 +637,7 @@ public abstract class W3CTS {
    * @param msg message
    * @throws IOException I/O exception
    */
-  private void addLog(final String pth, final String nm, final String msg)
-      throws IOException {
+  private void addLog(final String pth, final String nm, final String msg) throws IOException {
 
     if(reporting) {
       final File file = new File(results + pth);
@@ -731,8 +730,7 @@ public abstract class W3CTS {
    * @throws QueryException query exception
    */
   @SuppressWarnings("unused")
-  protected void parse(final QueryProcessor qp, final Nodes root)
-      throws QueryException { }
+  protected void parse(final QueryProcessor qp, final Nodes root) throws QueryException { }
 
   /**
    * Returns all query states.
@@ -753,25 +751,9 @@ public abstract class W3CTS {
     return false;
   }
 
-  /**
-   * Parses the command-line arguments, specified by the user.
-   * @param args command-line arguments
-   * @throws IOException I/O exception
-   */
-  protected final void parseArguments(final String[] args) throws IOException {
-    final Args arg = new Args(args, this,
-        " [options] [pat]" + NL +
-        " [pat] perform tests starting with a pattern" + NL +
-        " -c     print compilation steps" + NL +
-        " -C     run tests depending on current time" + NL +
-        " -g     <test-group> test group to test" + NL +
-        " -h     show this help" + NL +
-        " -m     minimum conformance" + NL +
-        " -p     change path" + NL +
-        " -r     create report" + NL +
-        " -t[ms] list slowest queries" + NL +
-        " -v     verbose output", Util.info(CONSOLE, Util.name(this)));
-
+  @Override
+  protected final void parseArgs() throws IOException {
+    final MainParser arg = new MainParser(this);
     while(arg.more()) {
       if(arg.dash()) {
         final char c = arg.next();
@@ -793,7 +775,7 @@ public abstract class W3CTS {
         } else if(c == 'v') {
           verbose = true;
         } else {
-          arg.usage();
+          throw arg.usage();
         }
       } else {
         single = arg.string();
@@ -809,4 +791,24 @@ public abstract class W3CTS {
   private IOFile sandbox() {
     return new IOFile(Prop.TMP, testid);
   }
+
+  @Override
+  public String header() {
+    return Util.info(S_CONSOLE, Util.className(this));
+  }
+
+  @Override
+  public String usage() {
+    return " [options] [pat]" + NL +
+        " [pat] perform tests starting with a pattern" + NL +
+        " -c     print compilation steps" + NL +
+        " -C     run tests depending on current time" + NL +
+        " -g     <test-group> test group to test" + NL +
+        " -h     show this help" + NL +
+        " -m     minimum conformance" + NL +
+        " -p     change path" + NL +
+        " -r     create report" + NL +
+        " -t[ms] list slowest queries" + NL +
+        " -v     verbose output";
+  }
 }
