@@ -6,7 +6,7 @@ import org.basex.util.*;
 /**
  * XQuery Test Suite wrapper.
  *
- * @author BaseX Team 2005-13, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public final class XQTS extends W3CTS {
@@ -16,14 +16,15 @@ public final class XQTS extends W3CTS {
    * @throws Exception exception
    */
   public static void main(final String[] args) throws Exception {
-    new XQTS().run(args);
+    new XQTS(args).run();
   }
 
   /**
    * Constructor.
+   * @param args command-line arguments
    */
-  public XQTS() {
-    super(Util.name(XQTS.class));
-    context.prop.set(Prop.XQUERY3, false);
+  public XQTS(final String[] args) {
+    super(args, Util.className(XQTS.class));
+    context.options.set(MainOptions.XQUERY3, false);
   }
 }
