@@ -8,7 +8,7 @@ import org.basex.util.*;
 /**
  * XQuery Update Test Suite wrapper.
  *
- * @author BaseX Team 2005-13, BSD License
+ * @author BaseX Team 2005-14, BSD License
  * @author Christian Gruen
  */
 public final class XQUTS extends W3CTS {
@@ -18,15 +18,16 @@ public final class XQUTS extends W3CTS {
    * @throws Exception exception
    */
   public static void main(final String[] args) throws Exception {
-    new XQUTS().run(args);
+    new XQUTS(args).run();
   }
 
   /**
    * Constructor.
+   * @param args command-line arguments
    */
-  public XQUTS() {
-    super(Util.name(XQUTS.class));
-    context.prop.set(Prop.FORCECREATE, true);
+  public XQUTS(final String[] args) {
+    super(args, Util.className(XQUTS.class));
+    context.options.set(MainOptions.FORCECREATE, true);
   }
 
   @Override
